Create a transmission tree compatible with the provided phylogenetic tree
makeCTreeFromPTree(
ptree,
off.r = NA,
off.p = NA,
neg = NA,
pi = NA,
w.shape = NA,
w.scale = NA,
ws.shape = NA,
ws.scale = NA,
T = NA,
optiStart = 0
)Phylogenetic tree
First parameter of the negative binomial distribution for offspring number
Second parameter of the negative binomial distribution for offspring number
the within-host effective population size (Ne) timesgeneration duration (g)
probability of sampling an infected individual
Shape parameter of the Gamma probability density function representing the generation time
Scale parameter of the Gamma probability density function representing the generation time
Shape parameter of the Gamma probability density function representing the sampling time
Scale parameter of the Gamma probability density function representing the sampling time
Date when process stops (this can be Inf for fully simulated outbreaks)
Method used to optimised colored tree (0=none, 1=slow, 2=fast)
A minimal non-zero probability phylogenetic+transmission tree, or an optimised version if parameters are provided