Learn R Programming

TransPhylo (version 1.4.5)

phyloFromPTree: Converts a phylogenetic tree into an ape phylo object

Description

Converts a phylogenetic tree into an ape phylo object

Usage

phyloFromPTree(ptree)

Arguments

ptree

phylogenetic tree

Value

phylo object

Examples

Run this code
# NOT RUN {
phyloFromPTree(extractPTree(simulateOutbreak()))
# }

Run the code above in your browser using DataLab