Learn R Programming

TransPhylo (version 1.4.5)

probPTreeGivenTTree: Calculate the probability of a phylogenetic tree given a transmission tree

Description

Calculate the probability of a phylogenetic tree given a transmission tree

Usage

probPTreeGivenTTree(ctree, neg, w = integer(0))

Arguments

ctree

Combined phylogenetic/transmission tree

neg

Within-host coalescent rate

w

Vector of hosts for which to calculate the probability, or nothing for all

Value

Probability of phylogeny given transmission tree