Learn R Programming

TransPhylo (version 1.4.5)

ptreeFromPhylo: Converts an ape phylo object into a phylogenetic tree

Description

Converts an ape phylo object into a phylogenetic tree

Usage

ptreeFromPhylo(tr, dateLastSample)

Arguments

tr

phylo object

dateLastSample

date of the last sample

Value

phylogenetic tree

Examples

Run this code
# NOT RUN {
ptreeFromPhylo(ape::rtree(5),2020)
# }

Run the code above in your browser using DataLab