Infer transmission tree given a phylogenetic tree
inferTTree(
ptree,
w.shape = 2,
w.scale = 1,
ws.shape = NA,
ws.scale = NA,
w.mean = NA,
w.std = NA,
ws.mean = NA,
ws.std = NA,
mcmcIterations = 1000,
thinning = 1,
startNeg = 100/365,
startOff.r = 1,
startOff.p = 0.5,
startPi = 0.5,
updateNeg = TRUE,
updateOff.r = TRUE,
updateOff.p = FALSE,
updatePi = TRUE,
startCTree = NA,
updateTTree = TRUE,
optiStart = 2,
dateT = Inf,
verbose = F
)Phylogenetic tree
Shape parameter of the Gamma distribution representing the generation time
Scale parameter of the Gamma distribution representing the generation time
Shape parameter of the Gamma distribution representing the sampling time
Scale parameter of the Gamma distribution representing the sampling time
Mean of the Gamma distribution representing the generation time
Std of the Gamma distribution representing the generation time
Mean of the Gamma distribution representing the sampling time
Std of the Gamma distribution representing the sampling time
Number of MCMC iterations to run the algorithm for
MCMC thinning interval between two sampled iterations
Starting value of within-host coalescent parameter Ne*g
Starting value of parameter off.r
Starting value of parameter off.p
Starting value of sampling proportion pi
Whether of not to update the parameter Ne*g
Whether or not to update the parameter off.r
Whether or not to update the parameter off.p
Whether or not to update the parameter pi
Optional combined tree to start from
Whether or not to update the transmission tree
Type of optimisation to apply to MCMC start point (0=none, 1=slow, 2=fast)
Date when process stops (this can be Inf for fully simulated outbreaks)
Whether or not to use verbose mode (default is false)
posterior sample set of transmission trees
# NOT RUN {
inferTTree(ptreeFromPhylo(ape::rtree(5),2020),mcmcIterations=100)
# }
Run the code above in your browser using DataLab