probPTreeGivenTTreeR: Calculate the probability of a phylogenetic tree given a transmission tree
Description
Calculate the probability of a phylogenetic tree given a transmission tree
Usage
probPTreeGivenTTreeR(ctree, neg, w = NULL)
Arguments
ctree
Combined phylogenetic/transmission tree
neg
Within-host coalescent rate
w
Vector of hosts for which to calculate the probability, or NULL for all
Value
Probability of phylogeny given transmission tree